==> owncloud-10.0.3.tgz: owncloud/apps/federatedfilesharing/l10n/oc.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federated sharing",
    "Invalid Federated Cloud ID" : "ID Federated Cloud incorrècte",
    "Sharing %s failed, because this item is already shared with %s" : "Lo partiment de %s a fracassat perque aqueste objècte es ja partejat amb %s",
    "Not allowed to create a federated share with the same user" : "Pas autorizat a crear un partiment federat amb lo meteis utilizaire",
    "File is already shared with %s" : "Lo fichièr es ja partejat amb %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Lo partiment de %s a fracassat : impossible de trobar %s. Benlèu que lo servidor es momentanèament injonhable.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Recebètz \"/%3$s\" coma un partiment distant dempuèi %1$s (al nom de %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Recebètz \"/%3$s\" coma un partiment distant dempuèi %1$s",
    "Accept" : "Acceptar",
    "Decline" : "Refusar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Partejatz amb ieu gràcias a mon identificant Federated Cloud #owncloud %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Partejatz amb ieu gràcias a mon identificant Federated Cloud #owncloud",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Veire la documentacion",
    "Allow users on this server to send shares to other servers" : "Autorizar los utilizaires d'aqueste servidor a mandar de partiments cap a d'autres servidors",
    "Allow users on this server to receive shares from other servers" : "Autorizar los utilizaires d'aqueste servidor a recebre de partiments d'autres servidors",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Vòstre identificant Federated Cloud :",
    "Share it:" : "Partejar :",
    "Add to your website" : "Apondre a vòstre site web",
    "Share with me via ownCloud" : "Partejatz amb ieu via ownCloud",
    "HTML Code:" : "Còdi HTML :"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/federatedfilesharing/l10n/oc.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federated sharing",
    "Invalid Federated Cloud ID" : "ID Federated Cloud incorrècte",
    "Sharing %s failed, because this item is already shared with %s" : "Lo partiment de %s a fracassat perque aqueste objècte es ja partejat amb %s",
    "Not allowed to create a federated share with the same user" : "Pas autorizat a crear un partiment federat amb lo meteis utilizaire",
    "File is already shared with %s" : "Lo fichièr es ja partejat amb %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Lo partiment de %s a fracassat : impossible de trobar %s. Benlèu que lo servidor es momentanèament injonhable.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Recebètz \"/%3$s\" coma un partiment distant dempuèi %1$s (al nom de %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Recebètz \"/%3$s\" coma un partiment distant dempuèi %1$s",
    "Accept" : "Acceptar",
    "Decline" : "Refusar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Partejatz amb ieu gràcias a mon identificant Federated Cloud #owncloud %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Partejatz amb ieu gràcias a mon identificant Federated Cloud #owncloud",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Veire la documentacion",
    "Allow users on this server to send shares to other servers" : "Autorizar los utilizaires d'aqueste servidor a mandar de partiments cap a d'autres servidors",
    "Allow users on this server to receive shares from other servers" : "Autorizar los utilizaires d'aqueste servidor a recebre de partiments d'autres servidors",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Vòstre identificant Federated Cloud :",
    "Share it:" : "Partejar :",
    "Add to your website" : "Apondre a vòstre site web",
    "Share with me via ownCloud" : "Partejatz amb ieu via ownCloud",
    "HTML Code:" : "Còdi HTML :",
    "Add to your ownCloud" : "Apondre a vòstre ownCloud"
},
"nplurals=2; plural=(n > 1);");
